public inbox for binutils@sourceware.org
 help / color / mirror / Atom feed
* Re: ARM register names...
@ 2000-06-13 10:17 Nick Clifton
  0 siblings, 0 replies; 6+ messages in thread
From: Nick Clifton @ 2000-06-13 10:17 UTC (permalink / raw)
  To: scottb; +Cc: binutils

Hi Scott,

: I'd like to propose the following patch to allow the tools to default to the
: same register set that GCC uses by default.  Most of the assembly code in gcc,
: glibc and bfd uses this register set, and I find dumps using the standard set a
: little odd.
: 
: Scott
: 
: 2000-06-13  Scott Bambrough <scottb@netwinder.org>
: 
: 	* arm-dis.c (regnames): Add an additional register set to match the set used by
: 	gcc.  Make it the default.

Well I have no objection to this, although if you are going to change
the default names then I would suggest that you change them in GDB
too.

Approved.

Cheers
	Nick

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: ARM register names
  2011-12-05 13:31 Dave Pawson
@ 2011-12-05 17:32 ` nick clifton
  0 siblings, 0 replies; 6+ messages in thread
From: nick clifton @ 2011-12-05 17:32 UTC (permalink / raw)
  To: Dave Pawson; +Cc: bin-utils

Hi Dave,

> http://sourceware.org/binutils/docs/as/ARM_002dRegs.html#ARM_002dRegs
> isn't yet written.
>
> Anyone know where this information is available please?

You probably need the ARM Architecture Reference Manual.  This is 
available for free from ARM's website (although I think you need to 
register and give them an email address).

Section A2.6.1 has a table (A-22) which shows the names of these registers.

> I'm getting
> first.asm:33: VFP single precision register expected
> And I don't know what register names are expected?

Presumably one or more of S0 ... S31.

Cheers
   Nick


^ permalink raw reply	[flat|nested] 6+ messages in thread

* ARM register names
@ 2011-12-05 13:31 Dave Pawson
  2011-12-05 17:32 ` nick clifton
  0 siblings, 1 reply; 6+ messages in thread
From: Dave Pawson @ 2011-12-05 13:31 UTC (permalink / raw)
  To: bin-utils

http://sourceware.org/binutils/docs/as/ARM_002dRegs.html#ARM_002dRegs
isn't yet written.

Anyone know where this information is available please?
I'm getting
first.asm:33: VFP single precision register expected
And I don't know what register names are expected?


TIA

-- 
Dave Pawson
XSLT XSL-FO FAQ.
Docbook FAQ.
http://www.dpawson.co.uk

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: ARM register names...
  2000-06-13 10:45 George France
@ 2000-06-13 12:13 ` Scott Bambrough
  0 siblings, 0 replies; 6+ messages in thread
From: Scott Bambrough @ 2000-06-13 12:13 UTC (permalink / raw)
  To: George France; +Cc: binutils mailing list, Nick Clifton

George France wrote:
> 
> You may find it a little odd but having register dumps that match the ARM
> documentation is more useful in my humble opinion than gcc standard.

Why?  By far the most common register set used in my experience is the one gcc
uses.  I find it annoying to do a dump, and then have the function prologues,
PLT tables all look different than their original source.  When I look at a
frame pointer, I want it to be called fp, not r11.

The only difference between the standard set and the gcc is {r10, r11, r12} =
{sl, fp, ip}.  Under Linux I know that the got pointer is in sl, fp is the frame
pointer and ip is a scratch register, most commonly used in function prologues. 
Having these switched makes life difficult for me, and others here.

Finally these are GNU tools.  They should be consistent in this regard across
binutils, gcc, gdb etc...

However, I'm a reasonable guy.  If people hate this idea I won't commit it. 
Comments?

Scott

-- 
Scott Bambrough - Software Engineer
REBEL.COM    http://www.rebel.com
NetWinder    http://www.netwinder.org

^ permalink raw reply	[flat|nested] 6+ messages in thread

* RE: ARM register names...
@ 2000-06-13 10:45 George France
  2000-06-13 12:13 ` Scott Bambrough
  0 siblings, 1 reply; 6+ messages in thread
From: George France @ 2000-06-13 10:45 UTC (permalink / raw)
  To: 'Scott Bambrough', binutils mailing list; +Cc: Nick Clifton

Hello Scott;

You may find it a little odd but having register dumps that match the ARM
documentation is more useful in my humble opinion than gcc standard.

--George

George France,      france@crl.dec.com
Cambridge Research Laboratory, Compaq Computer Corporation
One Cambridgecenter    MS: CRL
Cambridge, MA 02142 USA



-----Original Message-----
From: Scott Bambrough [ mailto:scottb@netwinder.org ]
Sent: Tuesday, June 13, 2000 10:45 AM
To: binutils mailing list
Cc: Nick Clifton
Subject: ARM register names...


Hi Nick,

I'd like to propose the following patch to allow the tools to default to the
same register set that GCC uses by default.  Most of the assembly code in
gcc,
glibc and bfd uses this register set, and I find dumps using the standard
set a
little odd.

Scott

2000-06-13  Scott Bambrough <scottb@netwinder.org>

	* arm-dis.c (regnames): Add an additional register set to match the
set used by
	gcc.  Make it the default.

Index: arm-dis.c
===================================================================
RCS file: /cvs/src/src/opcodes/arm-dis.c,v
retrieving revision 1.15.2.1
diff -u -p -r1.15.2.1 arm-dis.c
--- arm-dis.c   2000/05/30 13:42:11     1.15.2.1
+++ arm-dis.c   2000/06/13 14:38:02
@@ -60,6 +60,8 @@ static arm_regname regnames[] =
 {
   { "raw" , "Select raw register names",
     { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10",
"r11",
"r12", "r13", "r14", "r15"}},
+  { "gcc",  "Select register names used by GCC",
+    { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "sl",
"fp", 
"ip",  "sp",  "lr",  "pc" }},
   { "std",  "Select register names used in ARM's ISA documentation",
     { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10",
"r11",
"r12", "sp",  "lr",  "pc" }},
   { "apcs", "Select register names used in the APCS",
@@ -70,7 +72,7 @@ static arm_regname regnames[] =
     { "a1", "a2", "a3", "a4", "v1", "v2", "v3", "WR", "v5", "SB", "SL",
"FP", 
"IP",  "SP",  "LR",  "PC" }}
 };
 
 /* Default to standard register name set.  */
 static unsigned int regname_selected = 1;
 
 #define NUM_ARM_REGNAMES  NUM_ELEM (regnames)
@@ -70,7 +72,7 @@ static arm_regname regnames[] =
 };
 
-/* Default to standard register name set.  */
+/* Default to GCC register name set.  */
 static unsigned int regname_selected = 1;
 
-- 
Scott Bambrough - Software Engineer
REBEL.COM    http://www.rebel.com
NetWinder    http://www.netwinder.org

^ permalink raw reply	[flat|nested] 6+ messages in thread

* ARM register names...
@ 2000-06-13  7:49 Scott Bambrough
  0 siblings, 0 replies; 6+ messages in thread
From: Scott Bambrough @ 2000-06-13  7:49 UTC (permalink / raw)
  To: binutils mailing list; +Cc: Nick Clifton

Hi Nick,

I'd like to propose the following patch to allow the tools to default to the
same register set that GCC uses by default.  Most of the assembly code in gcc,
glibc and bfd uses this register set, and I find dumps using the standard set a
little odd.

Scott

2000-06-13  Scott Bambrough <scottb@netwinder.org>

	* arm-dis.c (regnames): Add an additional register set to match the set used by
	gcc.  Make it the default.

Index: arm-dis.c
===================================================================
RCS file: /cvs/src/src/opcodes/arm-dis.c,v
retrieving revision 1.15.2.1
diff -u -p -r1.15.2.1 arm-dis.c
--- arm-dis.c   2000/05/30 13:42:11     1.15.2.1
+++ arm-dis.c   2000/06/13 14:38:02
@@ -60,6 +60,8 @@ static arm_regname regnames[] =
 {
   { "raw" , "Select raw register names",
     { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10", "r11",
"r12", "r13", "r14", "r15"}},
+  { "gcc",  "Select register names used by GCC",
+    { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "sl",  "fp", 
"ip",  "sp",  "lr",  "pc" }},
   { "std",  "Select register names used in ARM's ISA documentation",
     { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10", "r11",
"r12", "sp",  "lr",  "pc" }},
   { "apcs", "Select register names used in the APCS",
@@ -70,7 +72,7 @@ static arm_regname regnames[] =
     { "a1", "a2", "a3", "a4", "v1", "v2", "v3", "WR", "v5", "SB", "SL",  "FP", 
"IP",  "SP",  "LR",  "PC" }}
 };
 
 /* Default to standard register name set.  */
 static unsigned int regname_selected = 1;
 
 #define NUM_ARM_REGNAMES  NUM_ELEM (regnames)
@@ -70,7 +72,7 @@ static arm_regname regnames[] =
 };
 
-/* Default to standard register name set.  */
+/* Default to GCC register name set.  */
 static unsigned int regname_selected = 1;
 
-- 
Scott Bambrough - Software Engineer
REBEL.COM    http://www.rebel.com
NetWinder    http://www.netwinder.org

^ permalink raw reply	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2011-12-05 17:32 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2000-06-13 10:17 ARM register names Nick Clifton
  -- strict thread matches above, loose matches on Subject: below --
2011-12-05 13:31 Dave Pawson
2011-12-05 17:32 ` nick clifton
2000-06-13 10:45 George France
2000-06-13 12:13 ` Scott Bambrough
2000-06-13  7:49 Scott Bambrough

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).